@@ -1,20 +1,20 @@
 from .mixins import ExternalURLMixin, ImageMixin
-from .object import Object
+from .object import SpotifyObject
 
 
-class _BaseArtist(Object, ExternalURLMixin):
+class _BaseArtist(SpotifyObject, ExternalURLMixin):
 	_type = 'artist'
 
 	def __init__(self, client, data):
 		super().__init__(client, data)
 
-		self._fill_external_urls(data.pop('external_urls'))
+		ExternalURLMixin.__init__(self, data)
 
-	async def top_tracks(self, market='from_token'):
+	async def top_tracks(self, market=None):
 		'''
 		Returns this artists top tracks.
 
-		:param market: Market to find tracks for.
+		:param market: Market to find tracks for. Auto-resolved by the library if left blank.
 		:return: List[:class:`FullTrack`]
 		'''
 
@@ -29,9 +29,9 @@ class _BaseArtist(Object, ExternalURLMixin):
 
 		return await self._client.get_artist_related_artists(self.id)
 
-	async def albums(self, include_groups=None, country=None, limit=None, offset=None):
+	async def albums(self, limit=20, include_groups=None, country=None, offset=None):
 		'''
-		Get artist' albums
+		Get artists albums
 
 		:return: List[:class:`SimpleAlbum`]
 		'''
@@ -80,9 +80,9 @@ class FullArtist(_BaseArtist, ImageMixin):
 
 	def __init__(self, client, data):
 		super().__init__(client, data)
+		
+		ImageMixin.__init__(self, data)
 
 		self.follower_count = data['followers']['total']
 		self.genres = data.pop('genres')
 		self.popularity = data.pop('popularity')
-
-		self._fill_images(data.pop('images'))
