@@ -1,27 +1,22 @@
 from .mixins import ExternalURLMixin, ImageMixin
-from .object import Object
+from .object import SpotifyObject
 
 
-class _BaseUser(Object, ExternalURLMixin, ImageMixin):
+class _BaseUser(SpotifyObject, ExternalURLMixin, ImageMixin):
 	_type = 'user'
 
 	def __init__(self, client, data):
 		super().__init__(client, data)
 
+		ExternalURLMixin.__init__(self, data)
+		ImageMixin.__init__(self, data)
+
 		self.display_name = data.pop('display_name')
 		self.name = self.display_name
 
 		followers = data.get('followers', None)
 		self.follower_count = None if followers is None else followers['total']
 
-		self._fill_external_urls(data.pop('external_urls'))
-
-		images = data.pop('images', None)
-		if images is None:
-			self.images = []
-		else:
-			self._fill_images(images)
-
 	async def playlists(self):
 		'''
 		Get the users playlists.
@@ -40,7 +35,7 @@ class PublicUser(_BaseUser):
 		Spotify ID of the user.
 	name: str
 		Name of the user. Also aliased to the ``display_name`` attribute.
-	images: List[:class:`Image`] or None
+	images: List[:class:`Image`]
 		List of associated images, such as the users profile picture.
 	uri: str
 		Spotify URI of the user.
@@ -54,15 +49,30 @@ class PublicUser(_BaseUser):
 
 
 class PrivateUser(_BaseUser):
+	'''
+	Represents a private User object, usually fetched through the ``me`` endpoint.
+
+	This type has some additional attributes not existent in :class:`PublicUser`.
+
+	country: str
+		ISO-3166-1_ code of users country.
+	email: str
+		Email of user. Please do not this email is note necessarily verified by Spotify.
+	product: str
+		Users Spotify subscription level, could be ``free``, ``open`` or ``premium``. ``free`` and ``open`` are synonyms.
+	'''
+
 	def __init__(self, client, data):
 		super().__init__(client, data)
 
-		self.birthdate = data.pop('birthdate', None)
+		# this seems to have been removed from the api listing?
+		#self.birthdate = data.pop('birthdate', None)
+
 		self.country = data.pop('country', None)
 		self.email = data.pop('email', None)
 		self.product = data.pop('product', None)
 
-	async def top_tracks(self, limit=None, offset=None, time_range=None):
+	async def top_tracks(self, limit=20, offset=None, time_range=None):
 		'''
 		Gets the top tracks of the current user.
 
@@ -82,7 +92,7 @@ class PrivateUser(_BaseUser):
 
 		return await self._client.get_me_top_tracks(limit=limit, offset=offset, time_range=time_range)
 
-	async def top_artists(self, limit=None, offset=None, time_range=None):
+	async def top_artists(self, limit=20, offset=None, time_range=None):
 		'''
 		Get the top artists of the current user.
 
